#!/APSshare/epd/rh6-x86_64/bin/python

import time
import epics

def onChanges(pvname, char_value=None, **kws):
    print " %s now %s" % (pvname, char_value)

pvs = []
for i in range(36):
    me = epics.PV("id%2.2i:shutter" % (i+1))
    me.get(as_string=True)
    me.add_callback(onChanges)
    pvs.append(me)

while True:
    time.sleep(0.01)
