#!/APSshare/epd/rh6-x86_64/bin/python

import time
import epics

pvnames = ('id03:dval1', 'id03:dval2', 'id03:dval3',
           'id03:ival1', 'id03:ival2', 'id03:ival3')

pvs = []
for name in pvnames:
    pvs.append(epics.PV(name))

def onChanges(pvname, char_value=None, **kws):
    vals = [p.char_value for p in pvs]
    print time.ctime(),  ' |  '.join(vals)
    
for pv in pvs:
    pv.get()
    pv.add_callback(onChanges)
    
while True:
    time.sleep(0.001)
