#!/APSshare/epd/bin/rh6-x86_64/bin/python

import time
import numpy
import pylab

import epics

pv_dwave = epics.PV('id04:dwave')
pv_iwave = epics.PV('id04:iwave')

dwave = pv_dwave.get()
iwave = pv_iwave.get()

x = numpy.arange(len(dwave))

print 'DWave: sum, mean, std-dev = %.4f, %.4f, %.4f ' % (dwave.sum(), dwave.mean(), dwave.std())

pylab.plot(x, dwave)
pylab.show()

