#!/APSshare/epd/rh6-x86_64/bin/python

import time
import epics

pvnames = ('id03:dval1', 'id03:dval2', 'id03:dval3',
           'id03:ival1', 'id03:ival2', 'id03:ival3')

pvs = []
for name in pvnames:
    pvs.append(epics.PV(name))

while True:
    time.sleep(1.0)
    vals = []
    for p in pvs:
        vals.append(p.get(as_string=True))

    print time.ctime(),  ' |  '.join(vals)
