#!/APSshare/anaconda/bin/x86_64/bin/python

import time
import epics

class Thing(epics.Device):
    _fields = ('dval1', 'dval2', 'dval3',
               'ival1', 'ival1', 'ival3',
               'mbbo1', 'string1', 'filename')
    
    def __init__(self, prefix):
        epics.Device.__init__(self, prefix,
                              self._fields, delim=':')

t = Thing('id00')
t.filename = '/local/epics/Test.dat'

print 'Thing: filename waveform = ', t.filename
print 'Thing: filename string   = ', t.get('filename', as_string=True)

print 'Thing:  mbbo, dval1, ival1 ', t.mbbo1, t.dval1, t.ival1
print 'Thing:  mbbo as string     ', t.get('mbbo1', as_string=True)

